@@ -27,16 +27,16 @@ M_cvs::M_cvs(QWidget* parent, int id)
 
   setGeometry(MODULE_NEW_X, MODULE_NEW_Y, MODULE_DEFAULT_WIDTH, MODULE_CVS_HEIGHT);
   for (l1 = 0; l1 < MODULE_CVS_CV_COUNT; l1++) {
-    qs.sprintf("CV %d", l1);
+    qs = QString("CV %1").arg(l1);
     port_cv_out[l1] = new Port(qs, PORT_OUT, l1, this);
   }
 
   for (l1 = 0; l1 < MODULE_CVS_CV_COUNT; l1++) {
     cv[l1] = 0;
     cv_fine[l1] = 0;
-    qs.sprintf("&CV %d", l1);
+    qs = QString("&CV %1").arg(l1);
     configDialog->addSlider(qs, cv[l1], 0, 5);
-    qs.sprintf("CV %d &Fine", l1);
+    qs = QString("CV %1 &Fine").arg(l1);
     configDialog->addSlider(qs, cv_fine[l1], -0.5, 0.5);
   }
 }
