@@ -5,8 +5,8 @@
 
 void MidiControllerContext::setMidiValueRT(int value)
 {
-    for (typeof(mcAbles.constBegin()) it = mcAbles.constBegin();
-            it != mcAbles.constEnd(); it++) {
+    QList<MidiControllableBase*>::const_iterator it;
+    for (it = mcAbles.constBegin(); it != mcAbles.constEnd(); it++) {
         if ((*it)->setMidiValueRT(value)) {
             synthdata->mcSet.put(*it);
             synthdata->pipeMessage |= 1;
